package com.winhc.repal.controller;

import com.winhc.common.base.BeanResponse;
import com.winhc.common.enums.CodeMsg;
import com.winhc.repal.annotation.RolePermission;
import com.winhc.repal.enums.PermissionEnum;
import com.winhc.repal.model.dto.MemberRoleDTO;
import com.winhc.repal.model.dto.UpdateRolePermissionDTO;
import com.winhc.repal.model.vo.GroupRoleVO;
import com.winhc.repal.model.vo.RolePermissionVO;
import com.winhc.repal.service.RepalGroupRoleService;
import com.winhc.repal.service.RepalRolePermissionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description: 组织角色管理
 * @Author: xda
 * @Date: 2022/5/10 16:11
 */
@Api(tags = "组织角色管理")
@RestController
@RequestMapping(value = "/role")
public class RepalRoleController {

    @Autowired
    private RepalGroupRoleService repalGroupRoleService;

    @Autowired
    private RepalRolePermissionService repalRolePermissionService;

    @ApiOperation("新增角色")
    @RequestMapping(value = "/add", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.ROLE_SETUP)
    public BeanResponse<Long> addRole(@RequestBody MemberRoleDTO dto) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupRoleService.addRole(dto));
    }

    @ApiOperation("删除角色")
    @RequestMapping(value = "/del/{roleId}", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.ROLE_SETUP)
    public BeanResponse<Boolean> deleteRoleById(@PathVariable("roleId") Long roleId) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupRoleService.deleteRoleById(roleId));
    }

    @ApiOperation("获取所有权限编码和code")
    @RequestMapping(value = "/allPermission", method = RequestMethod.GET)
    public BeanResponse<List<RolePermissionVO>> getAllPermission() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalRolePermissionService.getAllPermission());
    }


    @ApiOperation("角色列表")
    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public BeanResponse<List<GroupRoleVO>> getGroupRoleList() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupRoleService.getGroupRoleList());
    }


    @ApiOperation("获取角色对应的权限列表")
    @RequestMapping(value = "/permission/{roleId}", method = RequestMethod.GET)
    public BeanResponse<List<RolePermissionVO>> getPermissionList(@PathVariable("roleId") Long roleId) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupRoleService.getPermissionList(roleId));
    }

    @ApiOperation("修改角色的权限")
    @RequestMapping(value = "/update", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.ROLE_SETUP)
    public BeanResponse<Boolean> updateRolePermission(@RequestBody UpdateRolePermissionDTO dto) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalRolePermissionService.updateRolePermission(dto));
    }

}
